nxp-pac

Crates

git

Versions

mcxa156

Flavors

MrccGlbCc1Clr

Struct MrccGlbCc1Clr 

#[repr(transparent)]
pub struct MrccGlbCc1Clr(pub u32);
AHB Clock Control Clear 1.

Tuple Fields

0: u32

Implementations

Source

impl MrccGlbCc1Clr

pub const fn data(&self) -> u32

Data array value, refer to corresponding position in MRCC_GLB_CCn.

pub const fn set_data(&mut self, val: u32)

Data array value, refer to corresponding position in MRCC_GLB_CCn.