nxp-pac

Crates

git

Versions

mcxa156

Flavors

MrccGlbRst1Set

Struct MrccGlbRst1Set 

#[repr(transparent)]
pub struct MrccGlbRst1Set(pub u32);
Peripheral Reset Control Set 1.

Tuple Fields

0: u32

Implementations

Source

impl MrccGlbRst1Set

pub const fn data(&self) -> u32

Data array value, refer to corresponding position in MRCC_GLB_RSTn.

pub const fn set_data(&mut self, val: u32)

Data array value, refer to corresponding position in MRCC_GLB_RSTn.